[Libreoffice-commits] core.git: bin/check-missing-unittests.py

Xisco Fauli (via logerrit) logerrit at kemper.freedesktop.org
Wed Jul 14 12:14:32 UTC 2021


 bin/check-missing-unittests.py |   12 +++++-------
 1 file changed, 5 insertions(+), 7 deletions(-)

New commits:
commit 03cdb7392bc79476f1725df6160e196497057882
Author:     Xisco Fauli <xiscofauli at libreoffice.org>
AuthorDate: Wed Jul 14 10:44:11 2021 +0200
Commit:     Xisco Fauli <xiscofauli at libreoffice.org>
CommitDate: Wed Jul 14 14:13:57 2021 +0200

    check-missing-unittests: only care about FIXED bugs
    
    Change-Id: Ifc13149acce6baa9e107e819b97ab879ff99d2d6
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/118887
    Tested-by: Jenkins
    Reviewed-by: Xisco Fauli <xiscofauli at libreoffice.org>

diff --git a/bin/check-missing-unittests.py b/bin/check-missing-unittests.py
index 50f329f6139d..c1efce6eda0e 100755
--- a/bin/check-missing-unittests.py
+++ b/bin/check-missing-unittests.py
@@ -14,9 +14,6 @@ import re
 import json
 import requests
 
-def isOpen(status):
-    return status == 'NEW' or status == 'ASSIGNED' or status == 'REOPENED'
-
 def splitList(lst, n):
     for i in range(0, len(lst), n):
         yield lst[i:i + n]
@@ -182,18 +179,19 @@ def main(ignoredBugs):
             print('\n=== ' + k1 + ' ===')
             for bugId, info in v1.items():
 
-                status = ''
+                resolution = ''
                 keywords = []
                 priority = ''
                 for bug in bugzillaJson:
                     if str(bug['id']) == str(bugId):
-                        status = bug['status']
+                        resolution = bug['resolution']
                         keywords = bug['keywords']
                         priority = bug['priority']
                         break
 
-                #Ignore open bugs, performance bugs and accessibility bugs
-                if status and not isOpen(status) and 'perf' not in keywords \
+                # Only care about FIXED bugs
+                # Ignore performance bugs and accessibility bugs
+                if resolution and resolution == 'FIXED' and 'perf' not in keywords \
                         and 'accessibility' not in keywords:
                     print(
                         "# {} - [{}] {} - [https://bugs.documentfoundation.org/show_bug.cgi?id={} tdf#{}]".format(


More information about the Libreoffice-commits mailing list